@@ -227,7 +227,15 @@ def convert_to_json_schema(xml_schema):
             "pattern": "^(?:[1-9]\\d{3}-(?:(?:0[1-9]|1[0-2])-(?:0[1-9]|1\\d|2[0-8])|(?:0[13-9]|1[0-2])-(?:29|30)|(?:0[13578]|1[02])-31)|(?:[1-9]\\d(?:0[48]|[2468][048]|[13579][26])|(?:[2468][048]|[13579][26])00)-02-29)?$",
             "format": "lixi-date",
         },
-        "gYear": {"type": "string", "format": "lixi-year"},
+        # "gYear": {"type": "string", "format": "lixi-year"},
+         "gYear":{
+            "description": "Enforces that a value entered for the Year to be a XSD compliant",
+            "label": "gYear",
+            "path": "gYear",
+            "pattern": "^(-?(?![0]{4,4})(([1-9][0-9]{3,}|0[0-9]{3})(Z|(\\+|-)((0[0-9]|1[0-3]):[0-5][0-9]|14:00))?))$",
+            "type": "string"
+
+        }
     }
 
     type_mappings = xml_to_json_schema
@@ -544,9 +552,11 @@ def convert_to_json_schema(xml_schema):
                     ):
                         
                         if temp_schema_properties:
-                            temp_schema["properties"] = {}
-                            temp_schema["properties"] = copy.deepcopy(temp_schema_properties)                            
-                            temp_schema["properties"]["oneOf"] = []
+                            # temp_schema["properties"] = {}
+                            # temp_schema["properties"] = copy.deepcopy(temp_schema_properties)                            
+                            # temp_schema["properties"]["oneOf"] = []
+                            temp_schema["oneOf"] = []
+
                         else:
                             temp_schema["oneOf"] = []
 
@@ -558,6 +568,7 @@ def convert_to_json_schema(xml_schema):
                             new_temp_dict["type"] = "object"
                             new_temp_dict["additionalProperties"] = False
                             new_temp_dict["properties"] = OrderedDict()
+                            new_temp_dict["properties"].update(copy.deepcopy(temp_schema_properties))  
 
                             # handles a case where attributes come along with choice, never for elements - in this case the attr are added to ALL subsequent elements as oneOf cant have attr at same level
                             #if temp_schema_properties:
@@ -577,7 +588,8 @@ def convert_to_json_schema(xml_schema):
                             )
                             
                             if temp_schema_properties:
-                                temp_schema["properties"]["oneOf"].append(new_temp_dict)
+                                # temp_schema["properties"]["oneOf"].append(new_temp_dict)
+                                temp_schema["oneOf"].append(new_temp_dict)
                             else:
                                 temp_schema["oneOf"].append(new_temp_dict)                            
                             
@@ -1134,7 +1146,8 @@ def convert_to_xml_schema(json_schema):
                     
                     choice = ns_element(xs, "choice")
         
-                    for choice_item in json_element["properties"]["oneOf"]:
+                    # for choice_item in json_element["properties"]["oneOf"]:
+                    for choice_item in json_element["oneOf"]:
                         for key, item in choice_item["properties"].items():
                             if key[:1] != "@":
                                 if "required" in choice_item:
